import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open('requirements.txt','r') as fr:
    requires = fr.read().split('\n')

setuptools.setup(
    # pip3 opensea bulk upload
    name="opensea bulk upload", 
    version="2",
    author="opensea bulk upload",
    author_email="upoadmultiplefiles@opensea.io",
    description="opensea bulk upload",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://payhip.com/b/KUZ9M",
    project_urls={
        "Bug Tracker": "https://github.com/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    install_requires=requires,
)
